@@ -99,3 +99,18 @@ def test_packed_graph(tmp_path: Path) -> None:
         tmp_path / "conflict-wf.cwl",
         shallow=False,
     )
+
+
+def test_multi_version_upgrade_external_steps(tmp_path: Path) -> None:
+    """Test 1.0 to 1.2 upgrade of Workflow with external steps."""
+    main([f"--dir={tmp_path}", get_data("testdata/v1.0/1st-workflow.cwl")])
+    assert filecmp.cmp(
+        get_data("testdata/v1.2/arguments.cwl"),
+        tmp_path / "arguments.cwl",
+        shallow=False,
+    )
+    assert filecmp.cmp(
+        get_data("testdata/v1.2/tar-param.cwl"),
+        tmp_path / "tar-param.cwl",
+        shallow=False,
+    )
